/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.cdi;

import java.util.logging.Logger;

import javax.enterprise.inject.spi.BeanManager;

import org.wamblee.inject.Injector;
import org.wamblee.inject.InjectorFactory;

/**
 * Factory that creates CDI injectors. This class may be subclassed for testing
 * to override the injectors that are returned.
 * 
 * @author Erik Brakkee
 */
public class CdiInjectorFactory implements InjectorFactory {

    private static final Logger LOGGER = Logger
        .getLogger(CdiInjectorFactory.class.getName());

    private BeanManager beanManager;

    /**
     * Constructs the factory using a default bean manager.
     * 
     * @throws IllegalArgumentException
     *             If bean manager is null.
     */
    public CdiInjectorFactory() {
        this(BeanManagerLookup.lookup());
    }

    /**
     * Constructs the factory using an explicit bean manager.
     * 
     * @param aBeanManager
     * @throws IllegalArgumentException
     *             If bean manager is null.
     */
    public CdiInjectorFactory(BeanManager aBeanManager) {
        if (aBeanManager == null) {
            throw new IllegalArgumentException("Bean manager is null");
        }
        beanManager = aBeanManager;
    }

    @Override
    public Injector create(Class aClass) {
        return new CdiInjector(beanManager, aClass);
    }

}
